Payload

Struct Payload 

pub struct Payload(/* private fields */);

Implementations

Source

impl Payload

pub fn encapsulate_message<K>( plaintext_message: &[u8], payload_keys: &[K], payload_size: usize, ) -> Result<Payload, Error>
where K: for<'a> SphinxPayloadKey<'a>,

Tries to encapsulate provided plaintext message inside a sphinx payload adding as many layers of encryption as there are keys provided. Note that the encryption layers are going to be added in reverse order!

pub fn unwrap<P>(self, payload_key: P) -> Result<Payload, Error>
where P: Borrow<[u8; 192]>,

Tries to remove single layer of encryption from self.

pub fn recover_plaintext(self) -> Result<Vec<u8>, Error>

After calling [unwrap] required number of times with correct payload_keys, tries to parse the resultant payload content into original encapsulated plaintext message.

pub fn len(&self) -> usize

pub fn as_bytes(&self) -> &[u8]

View this Payload as slice of bytes.

pub fn into_bytes(self) -> Vec<u8>

Convert this Payload as a vector of bytes.

pub fn from_bytes(bytes: &[u8]) -> Result<Payload, Error>

Tries to recover Payload from a slice of bytes.