PublicKey

Struct PublicKey 

pub struct PublicKey(/* private fields */);
A Diffie-Hellman public key

We implement Zeroize so that downstream consumers may derive it for Drop should they wish to erase public keys from memory. Note that this erasure (in this crate) does not automatically happen, but either must be derived for Drop or explicitly called.

Implementations

Source

impl PublicKey

pub fn to_bytes(&self) -> [u8; 32]

Convert this public key to a byte array.

pub fn as_bytes(&self) -> &[u8; 32]

View this public key as a byte array.