pub struct SphinxPacket {
pub header: SphinxHeader,
pub payload: Payload,
}Fields
header: SphinxHeaderpayload: PayloadImplementations
Sourceimpl SphinxPacket
impl SphinxPacket
pub fn new( message: Vec<u8>, route: &[Node], destination: &Destination, delays: &[Delay], ) -> Result<SphinxPacket, Error>
pub fn len(&self) -> usize
Sourcepub fn process_with_expanded_secret(
self,
expanded_shared_secret: &ExpandedSharedSecret,
) -> Result<ProcessedPacket, Error>
pub fn process_with_expanded_secret( self, expanded_shared_secret: &ExpandedSharedSecret, ) -> Result<ProcessedPacket, Error>
Processes the packet with the provided expanded secret. It could be useful in the situation where caller has already derived the value, because, for example, he had to obtain the reply tag.
pub fn process( self, node_secret_key: &StaticSecret, ) -> Result<ProcessedPacket, Error>
pub fn to_bytes(&self) -> Vec<u8> ⓘ
pub fn from_bytes(bytes: &[u8]) -> Result<SphinxPacket, Error>