pub struct Payload(/* private fields */);Implementations
Sourceimpl Payload
impl Payload
Sourcepub fn encapsulate_message<K>(
plaintext_message: &[u8],
payload_keys: &[K],
payload_size: usize,
) -> Result<Payload, Error>where
K: for<'a> SphinxPayloadKey<'a>,
pub fn encapsulate_message<K>(
plaintext_message: &[u8],
payload_keys: &[K],
payload_size: usize,
) -> Result<Payload, Error>where
K: for<'a> SphinxPayloadKey<'a>,
Tries to encapsulate provided plaintext message inside a sphinx payload adding as many layers of encryption as there are keys provided. Note that the encryption layers are going to be added in reverse order!
Sourcepub fn unwrap<P>(self, payload_key: P) -> Result<Payload, Error>
pub fn unwrap<P>(self, payload_key: P) -> Result<Payload, Error>
Tries to remove single layer of encryption from self.
Sourcepub fn recover_plaintext(self) -> Result<Vec<u8>, Error>
pub fn recover_plaintext(self) -> Result<Vec<u8>, Error>
After calling [unwrap] required number of times with correct payload_keys, tries to parse
the resultant payload content into original encapsulated plaintext message.
pub fn len(&self) -> usize
Sourcepub fn into_bytes(self) -> Vec<u8> ⓘ
pub fn into_bytes(self) -> Vec<u8> ⓘ
Convert this Payload as a vector of bytes.