pub struct PublicKey(/* private fields */);Expand description
A Diffie-Hellman public key
We implement Zeroize so that downstream consumers may derive it for Drop
should they wish to erase public keys from memory. Note that this erasure
(in this crate) does not automatically happen, but either must be derived
for Drop or explicitly called.
Implementations